==> fotoalbum-0.33.tar.bz2: fotoalbum-0.33/src/gui_fltk/gui.h <==
/*
 * Copyright (C) 2005,2008  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#ifndef __GUI_H
# define __GUI_H

# include <vector>

# include <FL/Fl.H>
# include <FL/Fl_Menu_Bar.H>
# include <FL/Fl_Group.H>
# include <FL/Fl_Menu_Button.H>
# include <FL/Fl_Double_Window.H>
# include <FL/Fl_Shared_Image.H>

# include <FL/Fl_Box.H>
# include <FL/Fl_Tile.H>

# include "config.h"
# include "pictreebrowser.h"
# include "picgroup.h"
# include "picbox.h"
# include "optionen.h"
# include "backtask.h"
# include "../base/treeview.h"
# include "../base/treeitem.h"
# include "../base/blockingtask.h"


/**
 * Data related to a thumbnail in group view
 */
struct TGroupViewData
{
  char*             tooltip;
  Fl_Shared_Image*  thumbnail;
  TreeItem*         pic;
};

/**
 * Data to reconstruct windowed mode after fullscreen
 */
struct TWindowedData
{
  int win_x;
  int win_y;
  int win_w;
  int win_h;  
  int pane_x;
  int pane_y;
  int pane_w;
  int pane_h;  
};

class UserInterface
{
public:  // Methoden
  Fl_Double_Window* make_window(int argc, char* argv[], TreeView* mysource = (TreeView*)0);
  int loadFile(const char* filename);
  UserInterface();
  ~UserInterface();
  void updateRecentFilesMenu();
  void updateRecentFilesMenuPtr();
  
  void selectCurrentItem();
  bool hasData();
  
  void followLink(std::string linktext);
  
  /**
   * 
   */
  void setPicFullscreen();
  void setFullscreen();
  
  /**
   *
   */
  int displayItem(TreeItem* item, bool fAllowFullscreen = true);
  
  /**
   * 
   */
  int showContextMenu(int       m_x,
                      int       m_y,
                      TreeItem* item);
  
  /**
   * 
   */
  void popupAction(int nAction);
  
  /**
   * 
   */
  int save(bool fNewName);
  
  /**
   * 1:  the window can be closed
   * -1: do not close this window!
   */
  int askBeforeClosing();
  
  /**
   * toggle mark on the picture which is currently being displayed
   */
  void toggleMarkCurrentPic();
  
  /**
   * 
   */
  void newViewByDate(TreeGroupBase* group);
  
  /**
   * 
   */
  void newViewBySearch(TreeGroupBase* group,
                       SearchData     sd);
  
  /**
   * 
   */
  void newViewWithoutText(TreeGroupBase* group);
  
  /**
   * 
   */
  void saveOptions();
  
  /**
   * 
   */
  void optionsdlg();
  
  /**
   * 
   */
  void albumsettingsdlg();
  
  void setLastDisplayedAsLastPopupSingle();
  
  void SetPermissions();
  
  void Idle();
  
  void AfterCreation();
  
  int loadDir(const char* dirname, TreeGroupBase* pGroup, TreePicData::eDateTimeSource dtmethod);

public:  // Member
  enum eMenuCallback { SHOWPICS, FULLSCREEN_PICS, FULLSCREEN };
  
  Fl_Double_Window*              window;
  Fl_Menu_Bar*                   menuBar;
  Fl_Menu_Item*                  myMainMenu;
  Fl_Menu_Button*                popup;
  std::string                    myFilename;
  PicTreeBrowser*                browser;
  std::vector<TGroupViewData>    groupviewdata;
  PicBox*                        mainpane_pic;
  
  static char**                  arguments;
  
  /**
   * statisch, weil diese Liste für alle Fenster gilt
   */
  static Fl_Menu_Item*               recentFiles_Menu;
  
  /** 
   * Eine Liste aller UserInterface
   */
  static std::vector<UserInterface*> windowList;
  
  /**
   * Klasse mit Optionen
   */
  static T_optionen*                 opts;
  
  static BlockTaskManager blockingTasks;
  static BackTaskDlg*     backTaskDlg;
  
private: // Methoden   
  void enterFullscreen();
  std::string stringMaxLen(std::string  in,
                           unsigned int mlen);
  void addToPopup(bool fSep, const char* descr, int nAction);
  void setWindowTitle(const char* filename);
  
  void redrawViews();
  
  std::string GetSourcepath(TreeGroupBase* group);
  bool IsPermitted(unsigned int uMask);
private: // Member
  Fl_Tile*                       tile;
  TreeView*                      myData;
  
  PicGroup*                      mainpane_group;
  
  TreeItem* pDisplayReq;
  bool      fDispReqFullscreen;
  
  // not null and contains valid data if fullscreen is active:
  TWindowedData*                 windowed;
  
  /**
   * 
   */
  SimpleXMLTransfer* xmlpluginlist;
  
  /**
   * Pointer to single item of last popup menu
   */
  TreeItem* lastPopupSingleItem;
  
  /**
   * pointer to the last item which has been displayed
   */
  TreeItem* lastDisplayedItem;

  /**
   * pointer to the most current displayed group
   */
  TreeGroupBase* lastDisplayedGroup;
  
  /**
   * 
   */
  static bool fGimpHintShown;
  
  /**
   * 
   */
  std::string strWindowTitle;
};

#endif

==> fotoalbum-0.201.tar.bz2: fotoalbum-0.201/src/gui_fltk/gui.h <==
/*
 * Copyright (C) 2005,2008, 2012  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#ifndef __GUI_H
# define __GUI_H

# include <vector>
# include <inttypes.h>

# include <FL/Fl.H>
# include <FL/Fl_Menu_Bar.H>
# include <FL/Fl_Group.H>
# include <FL/Fl_Menu_Button.H>
# include <FL/Fl_Double_Window.H>
# include <FL/Fl_Shared_Image.H>

# include <FL/Fl_Box.H>
# include <FL/Fl_Tile.H>

# include "config.h"
# include "pictreebrowser.h"
# include "picgroup.h"
# include "picbox.h"
# include "optionen.h"
# include "backtask.h"
# include "../base/treeview.h"
# include "../base/pic.h"
# include "../base/blockingtask.h"


class PicButton;
class Export;

/**
 * Data related to a thumbnail in group view
 */
struct TGroupViewData
{
  char*             tooltip;
  Fl_Shared_Image*  thumbnail;
  ItPicInGroup*     pic;
};

/**
 * Data to reconstruct windowed mode after fullscreen
 */
struct TWindowedData
{
  int win_x;
  int win_y;
  int win_w;
  int win_h;  
  int pane_x;
  int pane_y;
  int pane_w;
  int pane_h;  
};

class UserInterface
{
public:  // Methoden
  Fl_Double_Window* make_window(int argc, char* argv[]);
  int loadFile(const char* filename);
  UserInterface();
  ~UserInterface();
  void updateRecentFilesMenu(bool fRecurse = true);
  
  /**
   * necessary after following a link from a comment
   */
  void Tree_ShowGroup(ItGroup* pGroup);
  
  bool hasData();
  
  void followLink(std::string linktext);
  
  /**
   * 
   */
  void setPicFullscreen();
  void setFullscreen();
  
  /**
   *
   */
  int displayItem(ItPicInGroup* item, bool fAllowFullscreen = true, bool fPluginIfUseful = false, int mx = 0, int my = 0);
  int displayGroup(ItGroup* item);
  
  /**
   * 
   */
  int showContextMenuGroup(int      m_x,
                           int      m_y,
                           ItGroup* item);
  
  /**
   * 
   */
  int showContextMenuPic(int           m_x,
                         int           m_y,
                         ItPicInGroup* item,
                         bool fOnlyPlugins = false);
  
  /**
   * 
   */
  void popupActionPic(int nAction);
  void popupActionGroup(int nAction);
  
  /**
   * 
   */
  int save(bool fNewName);
  
  /**
   * 1:  the window can be closed
   * -1: do not close this window!
   */
  int askBeforeClosing();
  
  /**
   * toggle mark on the picture which is currently being displayed
   */
  void toggleMarkCurrentPic();
  
  /**
   * 
   */
  void saveOptions();
  
  /**
   * 
   */
  void optionsdlg();
  
  /**
   * 
   */
  void albumsettingsdlg();
  
  void setLastDisplayedAsLastPopupSingle();
  
  void SetPermissions();
  
  void Idle();
  
  void AfterCreation();
  
  int loadDir(const char* dirname, ItGroup* pGroup, ItPic::eDateTimeSource dtmethod);
  
  ItGroup* GetLastDisplayedGroup() { return browser->itemSelected; };

  bool ThisButtonIsMine(PicButton* pButton);
  
public:  // Member
  enum eMenuCallback { FULLSCREEN_PICS, FULLSCREEN };
  
  Fl_Double_Window*              window;
  Fl_Menu_Bar*                   menuBar;
  Fl_Menu_Item*                  myMainMenu;
  Fl_Menu_Button*                popup;
  std::string                    myFilename;
  PicTreeBrowser*                browser;
  std::vector<TGroupViewData>    groupviewdata;
  PicBox*                        mainpane_pic;
  
  static char**                  arguments;
  
  /** 
   * Eine Liste aller UserInterface
   */
  static std::vector<UserInterface*> windowList;
  
  /**
   * Klasse mit Optionen
   */
  static T_optionen*                 opts;
  
  static BlockTaskManager blockingTasks;
  static BackTaskDlg*     backTaskDlg;
  
private: // Methoden   
  void enterFullscreen();
  std::string stringMaxLen(std::string  in,
                           unsigned int mlen);
  void addToPopup(bool fSep, const char* descr, intptr_t nAction, bool fGroup = false);
  void setWindowTitle(const char* filename);
  
  void redrawViews();
  
  std::string GetSourcepath(ItGroup* group);
  bool IsPermitted(unsigned int uMask);
  void ExportRun(Export& ex);
  void ExportMeta(ItGroup* pGroup, std::vector<ItPicInGroup*> vListPics, ItGroup* pPicParent);
  
private: // Member
  Fl_Tile*                       tile;
  TreeView*                      myData;
  
  PicGroup*                      mainpane_group;
  
  ItGroup*      pDisplayReqGroup;
  ItPicInGroup* pDisplayReq;
  bool          fDispReqFullscreen;
  
  // not null and contains valid data if fullscreen is active:
  TWindowedData*                 windowed;
  
  /**
   * 
   */
  SimpleXMLTransfer* xmlpluginlist;
  
  /**
   * Pointer to single item of last popup menu
   */
  ItPicInGroup* lastPopupSinglePic;
  ItGroup*      lastPopupGroup;
  
  /**
   * 
   */
  static bool fGimpHintShown;
  
  /**
   * 
   */
  std::string strWindowTitle;
  
  /**
   * 
   */
  int nScrollPosInGroup;
};

#endif
